@@ -7,26 +7,31 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-# In[17]:
+# In[ ]:
 
 
+#!/usr/bin/env python
+# coding: utf-8
+
 
-    
-import socket, pickle
 
 
 HOST = ""
 PORT = 0
 ini = False
+s = None
+_pickle = None
 
-
-def init(h,p):
+def init(h,p,__pickle):
 
         global HOST
         global PORT
         global init
         ini = True
-
+        global s
+        global _pickle
+        
+        _pickle = __pickle
         HOST = h
         PORT = p
 
@@ -34,12 +39,19 @@ def init(h,p):
     
 def start_server(host,port,debug = False):
 
-
+            global s
+            global _pickle
+        
+            if s == None:
+                raise RuntimeError("Not initialised. Call remfunc.init(host,port) first.")
+                
+               
+        
             if debug == True:
                 print ("Server is Listening.....")
             HOST = host
             PORT = port
-            s = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+            
             s.bind((HOST, PORT))
             s.listen(1)
 
@@ -65,7 +77,7 @@ def start_server(host,port,debug = False):
 
                     data = conn.recv(int(size.decode("utf-8")))
 
-                    code = pickle.loads(data)
+                    code = _pickle.loads(data)
                     block = '\n'.join(code.splitlines()[:-1])
 
                     result = None
@@ -80,9 +92,9 @@ def start_server(host,port,debug = False):
 
 
 
-                    resultsize = str(len(pickle.dumps(result,-1)))
+                    resultsize = str(len(_pickle.dumps(result,-1)))
 
-                    conn.send(pickle.dumps(resultsize))
+                    conn.send(_pickle.dumps(resultsize))
 
                     conn.send(result)
 
@@ -107,19 +119,20 @@ def start_server(host,port,debug = False):
             
 def do(code):
             
-            import socket, pickle
+           
             
             
             global HOST
             global PORT
-            global init
-           
+            global ini
+            global s
+            global _pickle
                 
-            if init == False:
+            if ini == False:
                 
                 raise RuntimeError("Client not initialized, run remfunc.init(HOST,PORT) first. You only need to do this once.")
             
-            s = socket.socket(socket.AF_INET,socket.SOCK_STREAM)
+           
             
             try:
                 
@@ -132,7 +145,7 @@ def do(code):
                 
             datatosend = code
             
-            size = str(len(pickle.dumbs(datatosend,-1)))
+            size = str(len(_pickle.dumbs(datatosend,-1)))
             
             rsize = None
             result = None
@@ -148,7 +161,7 @@ def do(code):
                 
             try:
                 
-                s.send(pickle.dumps(datatosend))
+                s.send(_pickle.dumps(datatosend))
                 
             except:
                 
@@ -168,7 +181,7 @@ def do(code):
                 
                 try:
                     
-                    result = pickle.loads(conn.recv(int(rsize.decode("utf-8"))))
+                    result = _pickle.loads(conn.recv(int(rsize.decode("utf-8"))))
                     return result
                 
                 except:
@@ -183,46 +196,3 @@ def do(code):
 
 
 
-                
-                
-
-            
-            
-            
-   
-            
-        
-        
-
-
-
- 
-
-
-# In[11]:
-
-
-
-
-
-# In[7]:
-
-
-
-
-
-# In[ ]:
-
-
-
-
-
-# In[ ]:
-
-
-
-
-
-# In[ ]:
-
-
